summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lisp/org.el12
1 files changed, 6 insertions, 6 deletions
diff --git a/lisp/org.el b/lisp/org.el
index 5bee96fb0..60c95a6ff 100644
--- a/lisp/org.el
+++ b/lisp/org.el
@@ -5489,14 +5489,14 @@ by a #."
(org-remove-flyspell-overlays-in nl-before-endline end-of-endline)
(cond
((and org-src-fontify-natively
- ;; Technically, according to
+ ;; Technically, according to the
;; `org-src-fontify-natively' docstring, we should
;; only fontify src blocks. However, it is common
- ;; to use undocumented fontification of example
- ;; blocks with undocumented language specifier.
- ;; Keep this undocumented feature for user
- ;; convenience.
- (member block-type '("src" "example")))
+ ;; to use undocumented fontification of export and
+ ;; example blocks. (The latter which do not support a
+ ;; language specifier.) Keep this undocumented feature
+ ;; for user convenience.
+ (member block-type '("src" "export" "example")))
(save-match-data
(org-src-font-lock-fontify-block (or lang "") block-start block-end))
(add-text-properties bol-after-beginline block-end '(src-block t)))